fitted.rq.counts: Extract Fitted Values from Quantile Regression Models for Counts
Description
This function extracts fitted values from objects of class rq.counts.
Usage
# S3 method for rq.counts
fitted(object, ...)
Value
a vector or a matrix or an array of fitted values.
Arguments
- object
an object of class rq.counts.
- ...
other arguments.